@@ -30,12 +30,18 @@ class CoverActuatorState(enum.Enum):
 class CoverActuator(Base):
     """Free@Home CoverActuator Class."""
 
-    _state_refresh_output_pairings: list[Pairing] = [
+    _state_refresh_pairings: list[Pairing] = [
         Pairing.AL_INFO_MOVE_UP_DOWN,
         Pairing.AL_CURRENT_ABSOLUTE_POSITION_BLINDS_PERCENTAGE,
         Pairing.AL_INFO_FORCE,
         Pairing.AL_CURRENT_ABSOLUTE_POSITION_SLATS_PERCENTAGE,
     ]
+    _callback_attributes: list[str] = [
+        "state",
+        "forced_position",
+        "position",
+        "tilt_position",
+    ]
 
     def __init__(
         self,
@@ -130,37 +136,39 @@ class CoverActuator(Base):
         await self._set_position_datapoint(str(value))
         self._position = value
 
-    def _refresh_state_from_output(self, output: dict[str, Any]) -> bool:
+    def _refresh_state_from_datapoint(self, datapoint: dict[str, Any]) -> str:
         """
         Refresh the state of the device from a given output.
 
         This will return whether the state was refreshed as a boolean value.
         """
-        if output.get("pairingID") == Pairing.AL_INFO_MOVE_UP_DOWN.value:
+        if datapoint.get("pairingID") == Pairing.AL_INFO_MOVE_UP_DOWN.value:
             try:
-                self._state = CoverActuatorState(output.get("value"))
+                self._state = CoverActuatorState(datapoint.get("value"))
             except ValueError:
                 self._state = CoverActuatorState.unknown
-            return True
-        if output.get("pairingID") == Pairing.AL_INFO_FORCE.value:
+            return "state"
+        if datapoint.get("pairingID") == Pairing.AL_INFO_FORCE.value:
             try:
-                self._forced_position = CoverActuatorForcedPosition(output.get("value"))
+                self._forced_position = CoverActuatorForcedPosition(
+                    datapoint.get("value")
+                )
             except ValueError:
                 self._forced_position = CoverActuatorForcedPosition.unknown
-            return True
+            return "forced_position"
         if (
-            output.get("pairingID")
+            datapoint.get("pairingID")
             == Pairing.AL_CURRENT_ABSOLUTE_POSITION_BLINDS_PERCENTAGE.value
         ):
-            self._position = int(float(output.get("value")))
-            return True
+            self._position = int(float(datapoint.get("value")))
+            return "position"
         if (
-            output.get("pairingID")
+            datapoint.get("pairingID")
             == Pairing.AL_CURRENT_ABSOLUTE_POSITION_SLATS_PERCENTAGE.value
         ):
-            self._tilt_position = int(float(output.get("value")))
-            return True
-        return False
+            self._tilt_position = int(float(datapoint.get("value")))
+            return "tilt_position"
+        return None
 
     async def _set_moving_datapoint(self, value: str):
         """Set the move_up_down datapoint on the api."""
